spoon.transports

Package spoon :: Package transports |
[hide private]
[frames] | no frames]

# Package transports

source code
Subpackage for link related objects. These are used for interaction between two nodes directly, and for creating connections.

Submodules | [hide private]
spoon.transports.spoontransport spoon.transports.transporthub

Classes | [hide private]
`` | TransportHub Where all of your transports connect to form your glorious new node.
`` | SpoonRPCHello This object is sent as a very simple form of initial negotiation.
`` | TransportException
`` | LinkMessage Link message is the wrapper which will contain messages sent between two directly connected nodes.
`` | SpoonTransport The spoon transport base class.
`` | x The spoon transport base class.

Variables | [hide private]
`` | __module__ = `'spoon'`

Variables Details | [hide private]

    ### __module__ None Value:
        'spoon'